======================
Python Risk Adjustment
======================


.. image:: https://img.shields.io/pypi/v/pyriskadjust.svg
        :target: https://pypi.python.org/pypi/pyriskadjust

.. image:: https://travis-ci.com/calyxhealth/pyriskadjust.svg?branch=master
        :target: https://travis-ci.com/calyxhealth/pyriskadjust

.. image:: https://readthedocs.org/projects/pyriskadjust/badge/?version=latest
        :target: https://pyriskadjust.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A python implementation of CMS's Medicare Risk Adjustment model based on Hierarchical Condition Categories (HCCs)

https://www.cms.gov/Medicare/Health-Plans/MedicareAdvtgSpecRateStats/Risk-Adjustors.html

* Free software: MIT license
* Documentation: https://pyriskadjust.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
